<?php
/**
 * Adds widget.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly
class Weblizar_facebook_feed_widgets extends WP_Widget {
	public function __construct() {
		parent::__construct(
			'customize_facebook_widget_feed', // Base ID
			esc_html__( 'Customize Social Feed', Wl_FACEBOOK_FEED ), // Name
			array( 'description' => esc_html__( 'Display Customize Social Feed Gallery', Wl_FACEBOOK_FEED ) ) // Args
		);
	}

	/*
* Front-end display of widget.
*
* @see WP_Widget::widget()
*
* @param array $args     Widget arguments.
@param array $instance Saved values from database.
*/
	public function widget( $args, $instance ) {
		$Title = apply_filters( 'feed_widget_title', $instance['Title'] );
		echo ($args['before_widget']);

		$FID = apply_filters( 'feed_widget_shortcode', $instance['Shortcode'] );

		if ( is_numeric( $FID ) ) {
			if ( ! empty( $instance['Title'] ) ) {
				echo wp_kses_post($args['before_title'] . apply_filters( 'widget_title', $instance['Title'] ) . $args['after_title']);
			} ?>
            <div class="feed_weblizar_widget">
				<?php echo do_shortcode( '[WFP id=' . $FID . ']' ); ?>
            </div>
		<?php } else {
			echo "<p>" . esc_html__( 'Sorry! No Customize Social Feed Shortcode Found.', Wl_FACEBOOK_FEED ) . "</p>";
		}
		echo wp_kses_post($args['after_widget']);
		wp_reset_query();
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		if ( isset( $instance['Title'] ) ) {
			$Title = $instance['Title'];
		} else {
			$Title = "Customize Social Feed";
		}
		if ( isset( $instance['Shortcode'] ) ) {
			$Shortcode = $instance['Shortcode'];
		} else {
			$Shortcode = esc_html__( "Select Any Weblizar Facebook Feed Shortcode", Wl_FACEBOOK_FEED );
		} ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id( 'Title' )); ?>"><?php esc_html_e( 'Widget Title' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'Title' )); ?>"
                   name="<?php echo esc_attr($this->get_field_name( 'Title' )); ?>" type="text"
                   value="<?php echo esc_attr( $Title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id( 'Shortcode' )); ?>"><?php esc_html_e( 'Select Any' ); ?><?php esc_html_e( 'Required', Wl_FACEBOOK_FEED ); ?></label>
			<?php
			/**
			 * Get All Facebook Shortcode Custom Post Type
			 */
			$FEED_CPT_Name  = "wl_fb_feed";
			$FEED_All_Posts = wp_count_posts( $FEED_CPT_Name )->publish;
			global $All_Feed;
			$All_Feed = array( 'post_type' => $FEED_CPT_Name, 'orderby' => 'ASC', 'posts_per_page' => $FEED_All_Posts );
			$All_Feed = new WP_Query( $All_Feed );
			?>
            <select id="<?php echo esc_attr($this->get_field_id( 'Shortcode' )); ?>"
                    name="<?php echo esc_attr($this->get_field_name( 'Shortcode' )); ?>" style="width: 100%;">
                <option value="Select Any Settings" <?php if ( $Shortcode == "Select Any Settings" ) {
					echo 'selected="selected"';
				} ?>> <?php esc_html_e( 'Select Any Settings', Wl_FACEBOOK_FEED ); ?></option>
				<?php
				if ( $All_Feed->have_posts() ) { ?>
					<?php while ( $All_Feed->have_posts() ) : $All_Feed->the_post();
						$PostId    = get_the_ID();
						$PostTitle = get_the_title( $PostId );
						?>
                        <option value="<?php echo esc_attr($PostId); ?>" <?php if ( $Shortcode == $PostId ) {
							echo 'selected="selected"';
						} ?>><?php if ( $PostTitle ) {
								echo esc_html($PostTitle);
							} else {
								esc_html_e( "No Title", Wl_FACEBOOK_FEED );
							} ?> </option>
					<?php endwhile; ?>
				<?php } else {
					echo "<option>" . esc_html__( 'Sorry! No Customize Social Feed Shortcode Found.', Wl_FACEBOOK_FEED ) . "</option>";
				} ?>
            </select>
        </p>

	<?php }

	public function update( $new_instance, $old_instance ) {
		$instance              = array();
		$instance['Title']     = ( ! empty( $new_instance['Title'] ) ) ? strip_tags( $new_instance['Title'] ) : '';
		$instance['Shortcode'] = ( ! empty( $new_instance['Shortcode'] ) ) ? strip_tags( $new_instance['Shortcode'] ) : 'Select Any Flickr Album Gallery';

		return $instance;
	}
}

add_action( 'widgets_init', 'register_Weblizar_facebook_feed_widgets' );
function register_Weblizar_facebook_feed_widgets() {
	register_widget( 'Weblizar_facebook_feed_widgets' );
} ?>